%%%%%%%%%%%%%%%%%%%%%%%%%%
% This Class is for the Tesi Style of the University
% of Florence.
% The book LaTeX2e class is used and modified.
% T. Pecorella, DIE, via S. Marta 3, 50139, Firenze
% pecos@lenst.die.unifi.it
% F. Bartolini, DIE, via S. Marta 3, 50139, Firenze
% barto@cosimo.ing.unifi.it
%
% Adapted for the University of Naples by
% Antonio Ospite <ospite@studenti.unina.it>
%
%  You need LaTeX2e with the graphics bundle installed.
%  You also need the babel package installed for getting
%      italian hyphenation and names
%
%   Usage:
%       \documentclass[twoside|oneside,10pt|11pt|12pt]{tesi}
%   Default:
%       \documentclass[oneside,12pt]{tesi.cls}
%
%   Compulsory commands:
%       \title{......}             Thesis title
%       \author{......}            Thesis author
%       \titolocorso{......}       Laurea or doctorate course name
%       \chair{.......}            First thesis supervisor
%       \numberofmembers{..}       Number of supervisors (at least 1)
%       \degreeyear{......}        Accademic year of graduation
%   Available commands:
%       \othermembers{.....\mediskip\\....} Possible other supervisors
%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{tesi}
     [23/2/96 v1.0 Classe Latex per la tesi di T.Pecorella ---
       basata su UFtesi.cls by F. Bartolini, Dip. Ing. Elettronica -  Univ. Firenze]
\newcommand{\@ptoption}{}
\newcommand{\@tipo}{}
\DeclareOption{10pt}{\renewcommand{\@ptoption}{0pt}}
\DeclareOption{11pt}{\renewcommand{\@ptoption}{1pt}}
\DeclareOption{12pt}{\renewcommand{\@ptoption}{2pt}}
\DeclareOption{twoside}{\renewcommand{\@tipo}{twoside}}
\DeclareOption{oneside}{\renewcommand{\@tipo}{oneside}}
\ExecuteOptions{oneside,12pt}
\ProcessOptions\relax
%
% Load the book class for a4 paper dimension
%
\LoadClass[\@tipo,a4paper,1\@ptoption]{book}
%
% Additional package are used.
%  Look at CTAN if you need some of them.
%  CTAN mirror at ftp://ftp.dante.de/tex-archive
% 

% The babel package is required for italian.
\RequirePackage[italian]{babel}

% The amsmath package is required for good-looking formulas.
% [fleqn,reqno] is for left ragged formulas with right eq. numb.
\RequirePackage[fleqn,reqno]{amsmath}

% The graphicx package is required for inserting the University
% logo in the title page. 
%\RequirePackage{graphicx}

% The chapterbib package is required for the bibliograpy 
%  at the end of each chapter. 
\RequirePackage{chapterbib}

% The subfigure package is required for the subfigures
%  (two or more aligned figures) 
\RequirePackage[bf, hang]{subfigure}

% The setspace package is required for 1.5 linespace
\RequirePackage{setspace}
\onehalfspacing

%
% The following variables are defined for the thesis title page
% The name of the laurea course
\def\degree#1{\gdef\@degree{#1}}
% The Academic year the degree will be officially conferred
\def\degreeyear#1{\gdef\@degreeyear{#1}}
% The name of your committee's chair
\def\chair#1{\gdef\@chair{#1}}
% The names of your other committe members, one per line
\def\othermembers#1{\gdef\@othermembers{#1}}
% The number of committee members, which affects both the
% number of lines and the amount of space between lines
% on the approval page.
\def\@numberofmembers{3}
\def\@approvalspace{.75in}
\def\numberofmembers#1{\gdef\@numberofmembers{#1}
\ifnum \@numberofmembers > 3
  \gdef\@approvalspace{.5in}
\fi}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%   tesi   %%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\linespacing}{1.5}
\renewcommand{\baselinestretch}{\linespacing}
\newcommand{\rilegatura}{10mm}
\addtolength\oddsidemargin{\rilegatura}
\addtolength\evensidemargin{-\rilegatura}
\setlength{\headsep}{15mm}

%%%%%%%%%%%%%%%%%%%

% The abstract which is not present in the original
% LaTeX2e book class is inserted.
% The abstract definition is taken from the report class.
%
\if@titlepage
  \newenvironment{abstract}{%
      \titlepage
      \null\vfil
      \begin{center}
        \bfseries \abstractname
      \end{center}}
     {\par\vfil\null\endtitlepage}
\else
  \newenvironment{abstract}{%
      \if@twocolumn
        \section*{\abstractname}%
      \else
        \small
        \begin{center}%
          {\bfseries \abstractname\vspace{-.5em}\vspace{\z@}}%
        \end{center}%
        \quotation
      \fi}
      {\if@twocolumn\else\endquotation\fi}
\fi

% The titlepage environment is changed so that
% a 1 \baselinestretch is used.
% The global \baselinestretch (as defined by 
% the \linespacing command above) is then restored.
%
\renewenvironment{titlepage}
    {%
      \if@twocolumn
        \@restonecoltrue\onecolumn
      \else
        \@restonecolfalse\newpage
      \fi
      \renewcommand{\baselinestretch}{1.0}
      \thispagestyle{empty}%
      \if@compatibility
        \setcounter{page}{0}
      \else
        \setcounter{page}{1}%
      \fi}%
    {\if@restonecol\twocolumn \else \newpage \fi
      \renewcommand{\baselinestretch}{\linespacing}
      \setcounter{page}{1}%
    }

% The \maketitle command is adapted to build a
% title page suitable for the University of Florence.
%
\renewcommand{\maketitle}
{\begin{titlepage}%
  \let\footnotesize\small
  \let\footnoterule\relax
  \begin{singlespace}
  \hspace*{-\rilegatura}
  \vspace*{-25mm}
  \begin{center}
    \textsc{\Large Universit\`a degli Studi di Napoli Federico
    II}\\[-10pt]
    \rule{\linewidth}{0.01mm} \medskip\\[-0.3em]
    \centering{\includegraphics[height=25mm]{stemma}}\\[2em]
    {\Large Facolt\`a di Scienze Matematiche, Fisiche e
    Naturali}\medskip\\[1.5em]
    {\Large Corso di Laurea in\ \@degree}\\
    \vfill
    {\large Tesi di Laurea}\bigskip\bigskip\\[1.5em]
    {\huge \bf \@title}\\
  \vfill\vfill
  \end{center}
  \vfill%
  \parbox[t]{0.45\textwidth}{%
    \raggedright
    \ifnum \@numberofmembers > 1
      {\bf\Large Relatori} \\
    \else
      {\bf\Large Relatore} \\
    \fi
    {\large \@chair} \\
    \ifnum \@numberofmembers > 1
      {\large \@othermembers}
    \fi
  }%
  \hfill%
  \parbox[t]{0.45\textwidth}{%
    \raggedleft
    {\bf\Large Autore} \\
    {\large \@author} \\
  }%
  \vfill
  \begin{center}
    \rule{\linewidth}{0.01mm}\\
    {Anno Accademico \@degreeyear}
  \end{center}
  \end{singlespace}
  \end{titlepage}
  \setcounter{footnote}{0}%
  \let\thanks\relax\let\maketitle\relax
  \gdef\@thanks{}\gdef\@author{}\gdef\@title{}
}

% The page heading are changed. The uppercase forcing
% is avoided and a rule is inserted below the heading.
%
\if@twoside
  \def\ps@headings{%
      \let\@oddfoot\@empty\let\@evenfoot\@empty
      \def\@evenhead{\thepage\hfil\slshape\leftmark%
      \hspace{-\textwidth}\rule[-2mm]{\textwidth}{0.01mm}}%
      \def\@oddhead{{\slshape\rightmark}\hfil\thepage%
      \hspace{-\textwidth}\rule[-2mm]{\textwidth}{0.01mm}}%
      \let\@mkboth\markboth
    \def\chaptermark##1{%
      \markboth {
        \ifnum \c@secnumdepth >\m@ne
          \if@mainmatter
            \@chapapp\ \thechapter. \ %
          \fi
        \fi
        ##1}{}}%
    \def\sectionmark##1{%
      \markright {%
        \ifnum \c@secnumdepth >\z@
          \thesection. \ %
        \fi
        ##1}}}
\else
  \def\ps@headings{%
    \let\@oddfoot\@empty
    \def\@oddhead{{\slshape\rightmark}\hfil\thepage%
    \hspace{-\textwidth}\rule[-2mm]{\textwidth}{0.01mm}}%
    \let\@mkboth\markboth
    \def\chaptermark##1{%
      \markright {%
        \ifnum \c@secnumdepth >\m@ne
          \if@mainmatter
            \@chapapp\ \thechapter. \ %
          \fi
        \fi
        ##1}}}
\fi

% The caption is changed so that a \small font is used.
%
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \begin{singlespace}
  \sbox\@tempboxa{{\small #1: #2}}%
  \ifdim \wd\@tempboxa >\hsize
    {\small #1: #2}\par
  \else
    \global \@minipagefalse
    \hbox to\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \end{singlespace}
  \vskip\belowcaptionskip}
%
% The \tableofcontents command is changed so that
% the \uppercase forcing of the header is avoided
%
\renewcommand{\tableofcontents}{%
    \begin{singlespace}
    \if@twocolumn
      \@restonecoltrue\onecolumn
    \else
      \@restonecolfalse
    \fi
    \chapter*{\contentsname
        \@mkboth{\contentsname}{\contentsname}}%
    \@starttoc{toc}%
    \if@restonecol\twocolumn\fi
    \end{singlespace}
    }
%
% The \listoffigures command is changed so that
% the \uppercase forcing of the header is avoided
%
\renewcommand{\listoffigures}{%
    \begin{singlespace}
    \if@twocolumn
      \@restonecoltrue\onecolumn
    \else
      \@restonecolfalse
    \fi
    \chapter*{\listfigurename
      \@mkboth{\listfigurename}%
              {\listfigurename}}%
    \@starttoc{lof}%
    \if@restonecol\twocolumn\fi
    \end{singlespace}
    }
%
% The \listoftables command is changed so that
% the \uppercase forcing of the header is avoided
%
\renewcommand{\listoftables}{%
    \begin{singlespace}
    \if@twocolumn
      \@restonecoltrue\onecolumn
    \else
      \@restonecolfalse
    \fi
    \chapter*{\l isttablename
      \@mkboth{\listtablename}{\listtablename}}%
    \@starttoc{lot}%
    \if@restonecol\twocolumn\fi
    \end{singlespace}
    }

% The \part command is changed so that the page number is
% not inserted in the part starting page.
%
\renewcommand{\part}{\cleardoublepage
                 \thispagestyle{empty}%
                 \if@twocolumn
                     \onecolumn
                     \@tempswatrue
                   \else
                     \@tempswafalse
                 \fi
                 \hbox{}\vfil
                 \secdef\@part\@spart}
%
% The \chapter command is changed so that the page number is
% not inserted in the chapter starting page.
%
\renewcommand{\chapter}{\if@openright\cleardoublepage\else\clearpage\fi
                    \thispagestyle{empty}%
                    \global\@topnum\z@
                    \@afterindentfalse
                    \secdef\@chapter\@schapter}
